@@ -265,6 +265,10 @@ class AsyncPushbullet(Pushbullet):
         """
         _ = await self.aio_session()
 
+    async def connect(self):
+        await self.aio_session()
+        return self
+
     async def aio_session(self) -> aiohttp.ClientSession:
         """Returns an open aiohttp.ClientSession with API key verified and timestamp
          of latest push updated.
@@ -982,3 +986,44 @@ class AsyncPushbullet(Pushbullet):
         data = xfer.get("data")
         xfer["msg"] = await self._async_push(data)
         return next(gen)
+
+    # Transfer file sub-function
+    async def async_push_file_simple(self,
+                               file_path: str,
+                               use_transfer_sh: bool = True,
+                               quiet: bool = False,
+                               title: str = None,
+                               body: str = None,
+                               target_device: Device = None):
+        if not os.path.isfile(file_path):
+            # TODO: this error handler is from the command line version
+            print("File not found:", file_path, file=sys.stderr)
+            return
+
+        show_progress = not quiet
+        if use_transfer_sh:
+            if not quiet:
+                print("Uploading file to transfer.sh ... {}".format(file_path))
+
+            info: Dict = await self.async_upload_file_to_transfer_sh(file_path=file_path,
+                                                                     show_progress=show_progress)
+
+        else:
+            if not quiet:
+                print("Uploading file to Pushbullet ... {}".format(file_path))
+            info: Dict = await self.async_upload_file(file_path=file_path,
+                                                      show_progress=show_progress)
+
+        file_url: str = info["file_url"]
+        file_type: str = info["file_type"]
+        file_name: str = info["file_name"]
+        if not quiet:
+            print("Pushing file ... {}".format(file_url))
+
+        title = title or "File: {}".format(file_name)
+        await self.async_push_file(file_name=file_name,
+                                   file_type=file_type,
+                                   file_url=file_url,
+                                   title=title,
+                                   body=body or file_url,
+                                   device=target_device)
