@@ -454,7 +454,8 @@ class ExecutableAction(Action):
 
             else:
                 # Pass the incoming push via stdin (json form)
-                input_bytes = json.dumps(push).encode(ENCODING)
+                # input_bytes = json.dumps(push).encode(ENCODING)
+                input_bytes = self.transform_push_to_stdin_data(push)
 
                 try:
                     # print("Awaiting process completion", self.path_to_executable, *self.args_for_exec)
@@ -487,10 +488,11 @@ class ExecutableAction(Action):
         # a different event loop, a ProactorLoop, to handle subprocesses.
         asyncio.run_coroutine_threadsafe(_on_proc_loop(), self.proc_loop)
 
-    # def transform_push_to_stdin_data(self, push: dict) -> bytes:
-    #     json_push = json.dumps(push)
-    #     input_bytes = json_push.encode(ENCODING)
-    #     return input_bytes
+    def transform_push_to_stdin_data(self, push: dict) -> bytes:
+        """Convert the push to something the process can read, json in this case"""
+        json_push = json.dumps(push)
+        input_bytes = json_push.encode(ENCODING)
+        return input_bytes
 
     async def handle_process_response(self, stdout_data: bytes, stderr_data: bytes, pb: AsyncPushbullet):
 
@@ -581,7 +583,7 @@ class ExecutableActionSimplified(ExecutableAction):
     def transform_push_to_stdin_data(self, push: dict) -> bytes:
         title = str(push.get("title", "")).strip().replace("\n", " ")
         body = str(push.get("body", ""))
-        output = "{}\n{}".format(title, body)
+        output = "{}\n{}".format(title, body).strip()
         output_bytes = output.encode(ENCODING)
         return output_bytes
 
