@@ -5,7 +5,7 @@ from __future__ import unicode_literals
 import sys
 from functools import update_wrapper
 
-import aiohttp
+# import aiohttp
 
 
 def use_appropriate_encoding(fn):
